#include <os2.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <io.h>

#include "ini.hpp"

// Method to read a line from the file and strip extra spaces & comments
// Returns "cleaned" string
char* /*__export*/ IniFile::Read( void )
{
  // Get next text line from the source file
  if ( ReadString() )
  {
    sBuffer[0] = 0;
    return sBuffer;
  }

  // Strip leading spaces
  char* curr_ptr = sBuffer;
  while ( *curr_ptr == ' ' || *curr_ptr == '\t' ) curr_ptr++;

  // Strip comments (the comment starts with the ";" character in the beginning
  //  of the text line or with the " ;" sequence in the middle of the line)
  char* semicolon = strchr( curr_ptr, ';' );
  if ( semicolon && ( semicolon == curr_ptr || *( semicolon - 1 ) == ' ' ||
    *( semicolon - 1 ) == '\t' ) ) *semicolon = 0;

  // Cut extra spaces in the end of line
  if ( *curr_ptr )
  {
    semicolon = curr_ptr + strlen( curr_ptr ) - 1;
    while( ( *semicolon == ' ' || *semicolon == 9 || *semicolon == 13 ||
       *semicolon == 10 ) && *semicolon ) *semicolon-- = 0;
  }

  return curr_ptr;
}

// Get the next value of the same entry
// Parameter: entry name
// Returns entry value
char* /*__export*/ IniFile::GetNext( char* pszEntry )
{
  if(!f) return NULL;

  // Read an input file until the end
  while ( ! feof( f ) )
  {
    char* s = Read();  //get the next line and strip spaces and comments

    if ( *s == '[' ) return NULL;  //return if we've reached the next section

    // Search for "=" char
    char* equals = strchr( s, '=' );
    if ( equals )
    {
      // Get the rest of line (all after "=")
      *equals = 0;
      if ( equals++ != s )
      {
        // Strip spaces between the entry name and "="
        char* entryend = equals - 2;
        while ( entryend > s && ( *entryend == ' ' || *entryend == 9 ) )
          *entryend-- = 0;
      }
    }

    // Compare entry name with given. Return the rest of line if OK
    if ( ! strcmp( s, pszEntry ) ) return equals;
  }

  // Otherwise return NULL
  return NULL;
}

// Method to get the first value of entry from specified section
// Parameters are:
//   pszSection - section name,
//   pszEntry - entry name,
//   pszDefault - default value (used when entry not found)
// Returns entry value in the static buffer
char* IniFile::Get( char* pszSection, char* pszEntry, char* pszDefault )
{
   if(!f) return pszDefault;

  // Rewind to the beginning if INI-file
  fseek( f, 0L, 0 );

  // Read an input file until the end
  while ( ! feof( f ) )
  {
    char* s = Read();  //get next line

    // Search for section name
    if ( s[0] == '[' )
    {
      char* close = strchr( ++s, ']' );
      if ( close )
      {
        *close = 0;

        // Compare section name with given
        if ( ! strcmp( s, pszSection ) )
        {
          // Look for an entry and return its value at success
          if ( (s = GetNext( pszEntry )) ) return s;
          else return pszDefault;  //otherwise return the default value
        }
      }
    }
  }
  return pszDefault;  //if section not found, return the default value
}


inline int atoi2( char *s )
{
  if ( s ) return atoi( s );
  else return 0;
}

inline int atoi3( char *s )
{
  if(!s) return 0;

  int q;

  sscanf(s, "%x",&q);
  return q;
}
