// INI-style file reader


const int iFFileMaxString = 4*CCHMAXPATH;

// Here is the class that represents a standard C file stream,
//  but has some features, e.g. auto-closing at destruction
class ffile
{
protected:
  unsigned uLinesGone;  //line counter (text files only)

public:

  FILE* f;  //pointer to FILE structure
  long lFileSize;  //file size (for read-only mode)
  char sBuffer[iFFileMaxString];  //buffer for text lines (text files only)

  ffile( char *pszFilename, const char* pszMode )  //Constructor (parameters
  {                                               //are the same as for fopen)
    //if ( f = fopen( pszFilename, pszMode ) ) // old
    if ( (f = fopen(pszFilename, pszMode )) != NULL )
    {
      lFileSize = filelength( fileno( f ) );
      uLinesGone = 0;
    }
  }

  ~ffile() { if ( f ) fclose( f ); }  //destructor that closes file

  FILE* operator()() { return f; }  //"()" operator - for use FILE
                                                                                                        //structure outside the class
  long GetPosition( void ) { return ftell( f ); }  //position in file

  int ReadString( void )  //method to read a single line from a text file
  {
    if ( feof( f ) || ! fgets( sBuffer, iFFileMaxString, f ) ) return -1;
    else { uLinesGone++; return 0; }
  }

  unsigned GetCurrLine( void ) { return uLinesGone; }  //current line number

  void Close( void ) { if ( fclose( f ) == 0 ) f = NULL; }
};

class /*__export*/ IniFile : public ffile
{
public:
  IniFile( char* pszFilename, const char* pszMode = "r" ) :  //Constructor
    ffile( pszFilename, pszMode ) {}                        //to open a file

  char* Read( void );  //Method to read a line from the file and strip
                     //extra spaces & comments

           //Method to get the first value of entry from specified section
  char* Get( char* pszSection, char* pszEntry, char* pszDefault = NULL );

  char* GetNext( char* pszEntry );  //Get the next value of the same entry

  int Feof() {return feof( f ); };
};

